@@ -2,11 +2,11 @@
 // called LICENSE at the top level of the ICU4X source tree
 // (online at: https://github.com/unicode-org/icu4x/blob/main/LICENSE ).
 
-use crate::uprops_helpers::{self, TomlBinary};
+use crate::uprops_helpers::{self, get_last_component_no_version, TomlBinary};
 
 use icu_properties::provider::UnicodePropertyV1;
 use icu_properties::provider::UnicodePropertyV1Marker;
-use icu_provider::iter::IterableDataProviderCore;
+use icu_provider::iter::IterableProvider;
 use icu_provider::prelude::*;
 use icu_uniset::UnicodeSetBuilder;
 use std::path::Path;
@@ -23,15 +23,15 @@ impl BinaryPropertyUnicodeSetDataProvider {
     }
 }
 
-impl<'data> DataProvider<'data, UnicodePropertyV1Marker> for BinaryPropertyUnicodeSetDataProvider {
+impl DataProvider<UnicodePropertyV1Marker> for BinaryPropertyUnicodeSetDataProvider {
     fn load_payload(
         &self,
         req: &DataRequest,
-    ) -> Result<DataResponse<'data, UnicodePropertyV1Marker>, DataError> {
+    ) -> Result<DataResponse<UnicodePropertyV1Marker>, DataError> {
         let data = &self
             .data
-            .get(&req.resource_path.key.sub_category)
-            .ok_or(DataError::MissingResourceKey(req.resource_path.key))?;
+            .get(get_last_component_no_version(&req.resource_path.key))
+            .ok_or_else(|| DataErrorKind::MissingResourceKey.with_req(req))?;
 
         let mut builder = UnicodeSetBuilder::new();
         for (start, end) in &data.ranges {
@@ -40,9 +40,7 @@ impl<'data> DataProvider<'data, UnicodePropertyV1Marker> for BinaryPropertyUnico
         let uniset = builder.build();
 
         Ok(DataResponse {
-            metadata: DataResponseMetadata {
-                data_langid: req.resource_path.options.langid.clone(),
-            },
+            metadata: DataResponseMetadata::default(),
             payload: Some(DataPayload::from_owned(
                 UnicodePropertyV1::from_owned_uniset(uniset),
             )),
@@ -52,9 +50,9 @@ impl<'data> DataProvider<'data, UnicodePropertyV1Marker> for BinaryPropertyUnico
 
 icu_provider::impl_dyn_provider!(BinaryPropertyUnicodeSetDataProvider, {
     _ => UnicodePropertyV1Marker,
-}, SERDE_SE, 'data);
+}, SERDE_SE);
 
-impl IterableDataProviderCore for BinaryPropertyUnicodeSetDataProvider {
+impl IterableProvider for BinaryPropertyUnicodeSetDataProvider {
     fn supported_options_for_key(
         &self,
         _resc_key: &ResourceKey,
@@ -70,11 +68,11 @@ fn test_basic() {
     use icu_uniset::UnicodeSet;
     use std::convert::TryInto;
 
-    let root_dir = icu_testdata::paths::data_root().join("uprops");
+    let root_dir = icu_testdata::paths::uprops_toml_root();
     let provider = BinaryPropertyUnicodeSetDataProvider::try_new(&root_dir)
         .expect("TOML should load successfully");
 
-    let payload: DataPayload<'_, UnicodePropertyV1Marker> = provider
+    let payload: DataPayload<UnicodePropertyV1Marker> = provider
         .load_payload(&DataRequest {
             resource_path: ResourcePath {
                 key: key::WHITE_SPACE_V1,
