@@ -2,14 +2,17 @@
 // called LICENSE at the top level of the ICU4X source tree
 // (online at: https://github.com/unicode-org/icu4x/blob/main/LICENSE ).
 
-use crate::uprops_helpers::{self, TomlEnumerated};
+use crate::uprops_helpers::{self, get_last_component_no_version, TomlEnumerated};
 use crate::uprops_serde::enumerated::EnumeratedPropertyCodePointTrie;
 
-use icu_codepointtrie::codepointtrie::{CodePointTrie, CodePointTrieHeader, TrieType, TrieValue};
+use icu_codepointtrie::{CodePointTrie, CodePointTrieHeader, TrieType, TrieValue};
 use icu_properties::provider::*;
 use icu_properties::provider::{UnicodePropertyMapV1, UnicodePropertyMapV1Marker};
-use icu_properties::{GeneralSubcategory, Script};
-use icu_provider::iter::IterableDataProviderCore;
+use icu_properties::{
+    CanonicalCombiningClass, EastAsianWidth, GeneralCategory, GraphemeClusterBreak, LineBreak,
+    Script, SentenceBreak, WordBreak,
+};
+use icu_provider::iter::IterableProvider;
 use icu_provider::prelude::*;
 use std::convert::TryFrom;
 use std::path::Path;
@@ -31,14 +34,18 @@ impl EnumeratedPropertyCodePointTrieProvider {
     }
 }
 
-impl<T: TrieValue> TryFrom<&EnumeratedPropertyCodePointTrie> for UnicodePropertyMapV1<'static, T> {
+// public helper function for doing the TOML->CodePointTrie conversion within
+// the source data -> data struct conversion
+impl<T: TrieValue> TryFrom<&EnumeratedPropertyCodePointTrie> for CodePointTrie<'static, T> {
     type Error = DataError;
 
     fn try_from(
         cpt_data: &EnumeratedPropertyCodePointTrie,
-    ) -> Result<UnicodePropertyMapV1<'static, T>, DataError> {
+    ) -> Result<CodePointTrie<'static, T>, Self::Error> {
         let trie_type_enum: TrieType =
-            TrieType::try_from(cpt_data.trie_type_enum_val).map_err(DataError::new_resc_error)?;
+            TrieType::try_from(cpt_data.trie_type_enum_val).map_err(|e| {
+                DataError::custom("Could not parse TrieType in TOML").with_display_context(&e)
+            })?;
         let header = CodePointTrieHeader {
             high_start: cpt_data.high_start,
             shifted12_high_start: cpt_data.shifted12_high_start,
@@ -47,7 +54,7 @@ impl<T: TrieValue> TryFrom<&EnumeratedPropertyCodePointTrie> for UnicodeProperty
             null_value: cpt_data.null_value,
             trie_type: trie_type_enum,
         };
-        let index: ZeroVec<u16> = ZeroVec::clone_from_slice(&cpt_data.index);
+        let index: ZeroVec<u16> = ZeroVec::alloc_from_slice(&cpt_data.index);
         let data: Result<ZeroVec<'static, T>, T::TryFromU32Error> =
             if let Some(data_8) = &cpt_data.data_8 {
                 data_8.iter().map(|i| T::try_from_u32(*i as u32)).collect()
@@ -56,54 +63,73 @@ impl<T: TrieValue> TryFrom<&EnumeratedPropertyCodePointTrie> for UnicodeProperty
             } else if let Some(data_32) = &cpt_data.data_32 {
                 data_32.iter().map(|i| T::try_from_u32(*i as u32)).collect()
             } else {
-                return Err(DataError::new_resc_error(
-                    icu_codepointtrie::error::Error::FromDeserialized {
-                        reason: "Did not find data array for CodePointTrie in TOML",
-                    },
+                return Err(DataError::custom(
+                    "Did not find data array for CodePointTrie in TOML",
                 ));
             };
 
-        let data = data.map_err(DataError::new_resc_error)?;
-        let trie =
-            CodePointTrie::<T>::try_new(header, index, data).map_err(DataError::new_resc_error);
+        let data = data.map_err(|e| {
+            DataError::custom("Could not parse data array in TOML").with_display_context(&e)
+        })?;
+
+        CodePointTrie::<T>::try_new(header, index, data).map_err(|e| {
+            DataError::custom("Could not create CodePointTrie from header/index/data array in TOML")
+                .with_display_context(&e)
+        })
+    }
+}
+
+// source data to ICU4X data struct conversion
+impl<T: TrieValue> TryFrom<&EnumeratedPropertyCodePointTrie> for UnicodePropertyMapV1<'static, T> {
+    type Error = DataError;
+
+    fn try_from(
+        cpt_data: &EnumeratedPropertyCodePointTrie,
+    ) -> Result<UnicodePropertyMapV1<'static, T>, DataError> {
+        let trie = CodePointTrie::<T>::try_from(cpt_data);
         trie.map(|t| UnicodePropertyMapV1 { code_point_trie: t })
     }
 }
 
-impl<'data, T: TrieValue> DataProvider<'data, UnicodePropertyMapV1Marker<T>>
+// implement data provider
+impl<T: TrieValue> DataProvider<UnicodePropertyMapV1Marker<T>>
     for EnumeratedPropertyCodePointTrieProvider
 {
     fn load_payload(
         &self,
         req: &DataRequest,
-    ) -> Result<DataResponse<'data, UnicodePropertyMapV1Marker<T>>, DataError> {
+    ) -> Result<DataResponse<UnicodePropertyMapV1Marker<T>>, DataError> {
         // For data resource keys that represent the CodePointTrie data for an enumerated
         // property, the ResourceKey sub-category string will just be the short alias
         // for the property.
-        let prop_name = &req.resource_path.key.sub_category;
+        let prop_name = get_last_component_no_version(&req.resource_path.key);
         let source_cpt_data = &self
             .data
             .get(prop_name)
-            .ok_or(DataError::MissingResourceKey(req.resource_path.key))?
+            .ok_or_else(|| DataErrorKind::MissingResourceKey.with_req(req))?
             .code_point_trie;
 
         let data_struct = UnicodePropertyMapV1::<T>::try_from(source_cpt_data)?;
 
         Ok(DataResponse {
-            metadata: DataResponseMetadata {
-                data_langid: req.resource_path.options.langid.clone(),
-            },
+            metadata: DataResponseMetadata::default(),
             payload: Some(DataPayload::from_owned(data_struct)),
         })
     }
 }
 
 icu_provider::impl_dyn_provider!(EnumeratedPropertyCodePointTrieProvider, {
-    key::GENERAL_CATEGORY_V1 => UnicodePropertyMapV1Marker<GeneralSubcategory>,
+    key::CANONICAL_COMBINING_CLASS_V1 => UnicodePropertyMapV1Marker<CanonicalCombiningClass>,
+    key::GENERAL_CATEGORY_V1 => UnicodePropertyMapV1Marker<GeneralCategory>,
     key::SCRIPT_V1 => UnicodePropertyMapV1Marker<Script>,
-}, SERDE_SE, 'data);
+    key::EAST_ASIAN_WIDTH_V1 => UnicodePropertyMapV1Marker<EastAsianWidth>,
+    key::LINE_BREAK_V1 => UnicodePropertyMapV1Marker<LineBreak>,
+    key::GRAPHEME_CLUSTER_BREAK_V1 => UnicodePropertyMapV1Marker<GraphemeClusterBreak>,
+    key::WORD_BREAK_V1 => UnicodePropertyMapV1Marker<WordBreak>,
+    key::SENTENCE_BREAK_V1 => UnicodePropertyMapV1Marker<SentenceBreak>,
+}, SERDE_SE);
 
-impl IterableDataProviderCore for EnumeratedPropertyCodePointTrieProvider {
+impl IterableProvider for EnumeratedPropertyCodePointTrieProvider {
     fn supported_options_for_key(
         &self,
         _resc_key: &ResourceKey,
@@ -116,21 +142,21 @@ impl IterableDataProviderCore for EnumeratedPropertyCodePointTrieProvider {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use icu_codepointtrie::codepointtrie::CodePointTrie;
+    use icu_codepointtrie::CodePointTrie;
     use icu_properties::provider::key;
-    use icu_properties::{GeneralSubcategory, Script};
+    use icu_properties::{GeneralCategory, Script};
 
     // A test of the UnicodeProperty General_Category is truly a test of the
-    // `GeneralSubcategory` Rust enum, not the `GeneralCategory` Rust enum,
+    // `GeneralCategory` Rust enum, not the `GeneralCategoryGroup` Rust enum,
     // since we must match the representation and value width of the data from
     // the ICU CodePointTrie that ICU4X is reading from.
     #[test]
     fn test_general_category() {
-        let root_dir = icu_testdata::paths::data_root().join("uprops");
+        let root_dir = icu_testdata::paths::uprops_toml_root();
         let provider = EnumeratedPropertyCodePointTrieProvider::try_new(&root_dir)
             .expect("TOML should load successfully");
 
-        let payload: DataPayload<'_, UnicodePropertyMapV1Marker<GeneralSubcategory>> = provider
+        let payload: DataPayload<UnicodePropertyMapV1Marker<GeneralCategory>> = provider
             .load_payload(&DataRequest {
                 resource_path: ResourcePath {
                     key: key::GENERAL_CATEGORY_V1,
@@ -141,19 +167,19 @@ mod tests {
             .take_payload()
             .expect("Loading was successful");
 
-        let trie: &CodePointTrie<GeneralSubcategory> = &payload.get().code_point_trie;
+        let trie: &CodePointTrie<GeneralCategory> = &payload.get().code_point_trie;
 
-        assert_eq!(trie.get('꣓' as u32), GeneralSubcategory::Digit);
-        assert_eq!(trie.get('≈' as u32), GeneralSubcategory::MathSymbol);
+        assert_eq!(trie.get('꣓' as u32), GeneralCategory::DecimalNumber);
+        assert_eq!(trie.get('≈' as u32), GeneralCategory::MathSymbol);
     }
 
     #[test]
     fn test_script() {
-        let root_dir = icu_testdata::paths::data_root().join("uprops");
+        let root_dir = icu_testdata::paths::uprops_toml_root();
         let provider = EnumeratedPropertyCodePointTrieProvider::try_new(&root_dir)
             .expect("TOML should load successfully");
 
-        let payload: DataPayload<'_, UnicodePropertyMapV1Marker<Script>> = provider
+        let payload: DataPayload<UnicodePropertyMapV1Marker<Script>> = provider
             .load_payload(&DataRequest {
                 resource_path: ResourcePath {
                     key: key::SCRIPT_V1,
