@@ -2,11 +2,11 @@
 // called LICENSE at the top level of the ICU4X source tree
 // (online at: https://github.com/unicode-org/icu4x/blob/main/LICENSE ).
 
-use crate::uprops_helpers::{self, TomlEnumerated};
+use crate::uprops_helpers::{self, get_last_component_no_version, TomlEnumerated};
 
 use icu_properties::provider::UnicodePropertyV1;
 use icu_properties::provider::UnicodePropertyV1Marker;
-use icu_provider::iter::IterableDataProviderCore;
+use icu_provider::iter::IterableProvider;
 use icu_provider::prelude::*;
 use icu_uniset::UnicodeSetBuilder;
 use std::path::Path;
@@ -26,28 +26,28 @@ impl EnumeratedPropertyUnicodeSetDataProvider {
 fn expand_groupings<'a>(prop_name: &str, prop_val: &'a str) -> Vec<&'a str> {
     match prop_name {
         "gc" => match prop_val {
-            // General_Category::CasedLetter
+            // GeneralCategoryGroup::CasedLetter
             "LC" => vec!["Lu", "Ll", "Lt"],
 
-            // General_Category::Letter
+            // GeneralCategoryGroup::Letter
             "L" => vec!["Lu", "Ll", "Lt", "Lm", "Lo"],
 
-            // General_Category::Mark
+            // GeneralCategoryGroup::Mark
             "M" => vec!["Mn", "Mc", "Me"],
 
-            // General_Category::Number
+            // GeneralCategoryGroup::Number
             "N" => vec!["Nd", "Nl", "No"],
 
-            // General_Category::Punctuation
+            // GeneralCategoryGroup::Punctuation
             "P" => vec!["Pc", "Pd", "Ps", "Pe", "Pi", "Pf", "Po"],
 
-            // General_Category::Symbol
+            // GeneralCategoryGroup::Symbol
             "S" => vec!["Sm", "Sc", "Sk", "So"],
 
-            // General_Category::Separator
+            // GeneralCategoryGroup::Separator
             "Z" => vec!["Zs", "Zl", "Zp"],
 
-            // General_Category::Control
+            // GeneralCategoryGroup::Control
             "C" => vec!["Cc", "Cf", "Cs", "Co", "Cn"],
 
             _ => vec![prop_val],
@@ -56,34 +56,29 @@ fn expand_groupings<'a>(prop_name: &str, prop_val: &'a str) -> Vec<&'a str> {
     }
 }
 
-impl<'data> DataProvider<'data, UnicodePropertyV1Marker>
-    for EnumeratedPropertyUnicodeSetDataProvider
-{
+impl DataProvider<UnicodePropertyV1Marker> for EnumeratedPropertyUnicodeSetDataProvider {
     fn load_payload(
         &self,
         req: &DataRequest,
-    ) -> Result<DataResponse<'data, UnicodePropertyV1Marker>, DataError> {
-        let key = &req.resource_path.key.sub_category;
+    ) -> Result<DataResponse<UnicodePropertyV1Marker>, DataError> {
+        let key = get_last_component_no_version(&req.resource_path.key);
 
         // ResourceKey subcategory strings for enumerated properties are
         // of the form "name=value", using the short name for both.
         let (prop_name, prop_value) = {
             let parts = key.split('=').collect::<Vec<_>>();
             if parts.len() != 2 {
-                return Err(DataError::MissingResourceKey(req.resource_path.key));
+                return Err(DataErrorKind::MissingResourceKey.with_req(req));
             }
-            (
-                parts[0].parse().map_err(DataError::new_resc_error)?,
-                parts[1],
-            )
+            (parts[0], parts[1])
         };
 
         let toml_data = &self
             .data
-            .get(&prop_name)
-            .ok_or(DataError::MissingResourceKey(req.resource_path.key))?;
+            .get(prop_name)
+            .ok_or_else(|| DataErrorKind::MissingResourceKey.with_req(req))?;
 
-        let valid_names = expand_groupings(&prop_name, prop_value);
+        let valid_names = expand_groupings(prop_name, prop_value);
 
         let mut builder = UnicodeSetBuilder::new();
         for range in &toml_data.ranges {
@@ -94,9 +89,7 @@ impl<'data> DataProvider<'data, UnicodePropertyV1Marker>
         let uniset = builder.build();
 
         Ok(DataResponse {
-            metadata: DataResponseMetadata {
-                data_langid: req.resource_path.options.langid.clone(),
-            },
+            metadata: DataResponseMetadata::default(),
             payload: Some(DataPayload::from_owned(
                 UnicodePropertyV1::from_owned_uniset(uniset),
             )),
@@ -106,9 +99,9 @@ impl<'data> DataProvider<'data, UnicodePropertyV1Marker>
 
 icu_provider::impl_dyn_provider!(EnumeratedPropertyUnicodeSetDataProvider, {
     _ => UnicodePropertyV1Marker,
-}, SERDE_SE, 'data);
+}, SERDE_SE);
 
-impl IterableDataProviderCore for EnumeratedPropertyUnicodeSetDataProvider {
+impl IterableProvider for EnumeratedPropertyUnicodeSetDataProvider {
     fn supported_options_for_key(
         &self,
         _resc_key: &ResourceKey,
@@ -128,11 +121,11 @@ mod tests {
         use icu_uniset::UnicodeSet;
         use std::convert::TryInto;
 
-        let root_dir = icu_testdata::paths::data_root().join("uprops");
+        let root_dir = icu_testdata::paths::uprops_toml_root();
         let provider = EnumeratedPropertyUnicodeSetDataProvider::try_new(&root_dir)
             .expect("TOML should load successfully");
 
-        let payload: DataPayload<'_, UnicodePropertyV1Marker> = provider
+        let payload: DataPayload<UnicodePropertyV1Marker> = provider
             .load_payload(&DataRequest {
                 resource_path: ResourcePath {
                     key: key::GENERAL_CATEGORY_NUMBER_V1,
@@ -157,11 +150,11 @@ mod tests {
         use icu_uniset::UnicodeSet;
         use std::convert::TryInto;
 
-        let root_dir = icu_testdata::paths::data_root().join("uprops");
+        let root_dir = icu_testdata::paths::uprops_toml_root();
         let provider = EnumeratedPropertyUnicodeSetDataProvider::try_new(&root_dir)
             .expect("TOML should load successfully");
 
-        let payload: DataPayload<'_, UnicodePropertyV1Marker> = provider
+        let payload: DataPayload<UnicodePropertyV1Marker> = provider
             .load_payload(&DataRequest {
                 resource_path: ResourcePath {
                     key: key::SCRIPT_THAI_V1,
@@ -186,13 +179,11 @@ mod tests {
         use icu_uniset::{UnicodeSet, UnicodeSetBuilder};
         use std::convert::TryInto;
 
-        fn get_uniset_payload<'data>(
-            key: ResourceKey,
-        ) -> DataPayload<'data, UnicodePropertyV1Marker> {
-            let root_dir = icu_testdata::paths::data_root().join("uprops");
+        fn get_uniset_payload(key: ResourceKey) -> DataPayload<UnicodePropertyV1Marker> {
+            let root_dir = icu_testdata::paths::uprops_toml_root();
             let provider = EnumeratedPropertyUnicodeSetDataProvider::try_new(&root_dir)
                 .expect("TOML should load successfully");
-            let payload: DataPayload<'_, UnicodePropertyV1Marker> = provider
+            let payload: DataPayload<UnicodePropertyV1Marker> = provider
                 .load_payload(&DataRequest {
                     resource_path: ResourcePath {
                         key,
@@ -302,11 +293,11 @@ mod tests {
         use icu_uniset::UnicodeSet;
         use std::convert::TryInto;
 
-        let root_dir = icu_testdata::paths::data_root().join("uprops");
+        let root_dir = icu_testdata::paths::uprops_toml_root();
         let provider = EnumeratedPropertyUnicodeSetDataProvider::try_new(&root_dir)
             .expect("TOML should load successfully");
 
-        let payload: DataPayload<'_, UnicodePropertyV1Marker> = provider
+        let payload: DataPayload<UnicodePropertyV1Marker> = provider
             .load_payload(&DataRequest {
                 resource_path: ResourcePath {
                     key: key::GENERAL_CATEGORY_SURROGATE_V1,
