@@ -22,8 +22,10 @@ mod enum_codepointtrie;
 mod enum_uniset;
 mod provider;
 mod reader;
+mod script;
 mod uprops_helpers;
 mod uprops_serde;
 
 pub use enum_codepointtrie::EnumeratedPropertyCodePointTrieProvider;
 pub use provider::PropertiesDataProvider;
+pub use script::ScriptExtensionsPropertyProvider;
