@@ -4,8 +4,9 @@
 
 use crate::bin_uniset::BinaryPropertyUnicodeSetDataProvider;
 use crate::enum_uniset::EnumeratedPropertyUnicodeSetDataProvider;
+use crate::uprops_helpers::get_last_component_no_version;
 use icu_properties::provider::UnicodePropertyV1Marker;
-use icu_provider::iter::IterableDataProviderCore;
+use icu_provider::iter::IterableProvider;
 use icu_provider::prelude::*;
 
 use std::path::Path;
@@ -29,12 +30,12 @@ impl PropertiesDataProvider {
     }
 }
 
-impl<'data> DataProvider<'data, UnicodePropertyV1Marker> for PropertiesDataProvider {
+impl DataProvider<UnicodePropertyV1Marker> for PropertiesDataProvider {
     fn load_payload(
         &self,
         req: &DataRequest,
-    ) -> Result<DataResponse<'data, UnicodePropertyV1Marker>, DataError> {
-        if req.resource_path.key.sub_category.contains('=') {
+    ) -> Result<DataResponse<UnicodePropertyV1Marker>, DataError> {
+        if get_last_component_no_version(&req.resource_path.key).contains('=') {
             self.enumerated.load_payload(req)
         } else {
             self.binary.load_payload(req)
@@ -44,9 +45,9 @@ impl<'data> DataProvider<'data, UnicodePropertyV1Marker> for PropertiesDataProvi
 
 icu_provider::impl_dyn_provider!(PropertiesDataProvider, {
     _ => UnicodePropertyV1Marker,
-}, SERDE_SE, 'data);
+}, SERDE_SE);
 
-impl IterableDataProviderCore for PropertiesDataProvider {
+impl IterableProvider for PropertiesDataProvider {
     fn supported_options_for_key(
         &self,
         _resc_key: &ResourceKey,
